; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Winmugen AI Commands |------------------------------------------------------

[Command]
name = "cpu1"
command = U, U, U, U
time = 0
[Command]
name = "cpu2"
command = U, U, U, D
time = 0
[Command]
name = "cpu3"
command = U, U, D, D
time = 0
[Command]
name = "cpu4"
command = U, D, D, D
time = 0
[Command]
name = "cpu5"
command = D, D, D, D
time = 0
[Command]
name = "cpu6"
command = D, D, D, U
time = 0
[Command]
name = "cpu7"
command = D, D, U, U
time = 0
[Command]
name = "cpu8"
command = D, U, U, U
time = 0
[Command]
name = "cpu9"
command = U, D, U, U
time = 0
[Command]
name = "cpu10"
command = U, U, D, U
time = 0
[Command]
name = "cpu11"
command = D, U, U, D
time = 0
[Command]
name = "cpu12"
command = U, D, D, U
time = 0
[Command]
name = "cpu13"
command = D, U, D, U
time = 0
[Command]
name = "cpu14"
command = U, D, U, D
time = 0
[Command]
name = "cpu15"
command = F, F, F, F
time = 0
[Command]
name = "cpu16"
command = B, B, B, B
time = 0
[Command]
name = "cpu17"
command = F, B, F, F
time = 0
[Command]
name = "cpu18"
command = F, F, B, F
time = 0
[Command]
name = "cpu19"
command = B, F, F, F
time = 0
[Command]
name = "cpu20"
command = F, F, F, B
time = 0
[Command]
name = "cpu21"
command = F, B, B, F
time = 0
[Command]
name = "cpu22"
command = B, F, F, B
time = 0
[Command]
name = "cpu23"
command = F, B, F, B
time = 0
[Command]
name = "cpu24"
command = B, F, B, F
time = 0
[Command]
name = "cpu25"
command = D, F, D, F
time = 0
[Command]
name = "cpu26"
command = D, B, D, B
time = 0
[Command]
name = "cpu27"
command = D, B, D, F
time = 0
[Command]
name = "cpu28"
command = D, F, D, B
time = 0
[Command]
name = "cpu29"
command = U, F, D, B
time = 0
[Command]
name = "cpu30"
command = U, B, D, F
time = 0
[Command]
name = "cpu31"
command = B, D, F, U
time = 0
[Command]
name = "cpu32"
command = F, D, B, U
time = 0
[Command]
name = "cpu33"
command = U, U, U, U
time = 0
[Command]
name = "cpu34"
command = U, U, U, D
time = 0
[Command]
name = "cpu35"
command = U, U, D, D
time = 0
[Command]
name = "cpu36"
command = U, D, D, D
time = 0
[Command]
name = "cpu37"
command = D, D, D, D
time = 0
[Command]
name = "cpu38"
command = D, D, D, U
time = 0
[Command]
name = "cpu39"
command = D, D, U, U
time = 0
[Command]
name = "cpu40"
command = D, U, U, U
time = 0
[Command]
name = "cpu41"
command = U, D, U, U
time = 0
[Command]
name = "cpu42"
command = U, U, D, U
time = 0
[Command]
name = "cpu43"
command = D, U, U, D
time = 0
[Command]
name = "cpu44"
command = U, D, D, U
time = 0
[Command]
name = "cpu45"
command = D, U, D, U
time = 0
[Command]
name = "cpu46"
command = U, D, U, D
time = 0
[Command]
name = "cpu47"
command = F, F, F, F
time = 0
[Command]
name = "cpu48"
command = B, B, B, B
time = 0
[Command]
name = "cpu49"
command = F, B, F, F
time = 0
[Command]
name = "cpu50"
command = F, F, B, F
time = 0
[Command]
name = "cpu51"
command = B, F, F, F
time = 0
[Command]
name = "cpu52"
command = F, F, F, B
time = 0
[Command]
name = "cpu53"
command = F, B, B, F
time = 0
[Command]
name = "cpu54"
command = B, F, F, B
time = 0
[Command]
name = "cpu55"
command = F, B, F, B
time = 0
[Command]
name = "cpu56"
command = B, F, B, F
time = 0
[Command]
name = "cpu57"
command = D, F, D, F
time = 0
[Command]
name = "cpu58"
command = D, B, D, B
time = 0
[Command]
name = "cpu59"
command = D, B, D, F
time = 0
[Command]
name = "cpu60"
command = D, F, D, B
time = 0
[Command]
name = "cpu61"
command = U, F, D, B
time = 0
[Command]
name = "cpu62"
command = U, B, D, F
time = 0
[Command]
name = "cpu63"
command = B, D, F, U
time = 0
[Command]
name = "cpu64"
command = F, D, B, U
time = 0

;-| Super Motions |-------------------------------------------------------
; Explosion Punch (SDM)
[Command]
name = "XplodSDM"
command = ~D, DB, B, D, DB, B, x+y
time = 30

; Explosion Punch (SDM)
[Command]
name = "XplodSDM"
command = ~D, DB, B, D, DB, B, y+z
time = 30

; Explosion Punch (SDM)
[Command]
name = "XplodSDM"
command = ~D, DB, B, D, DB, B, x+z
time = 30

; Explosion Punch (DM)
[Command]
name = "XplodDM"
command = ~D, DB, B, D, DB, B, x
time = 30

; Explosion Punch (DM)
[Command]
name = "XplodDM"
command = ~D, DB, B, D, DB, B, y
time = 30

; Explosion Punch (DM)
[Command]
name = "XplodDM"
command = ~D, DB, B, D, DB, B, z
time = 30

; Echidna Sequence Punches (SDM)
[Command]
name = "EchidnaSequenceSDM"
command = ~D, DF, F, D, DF, F, x+y
time = 30

; Echidna Sequence Punches (SDM)
[Command]
name = "EchidnaSequenceSDM"
command = ~D, DF, F, D, DF, F, y+z
time = 30

; Echidna Sequence Punches (SDM)
[Command]
name = "EchidnaSequenceSDM"
command = ~D, DF, F, D, DF, F, x+z
time = 30

; Echidna Sequence Punches (DM)
[Command]
name = "EchidnaSequence"
command = ~D, DF, F, D, DF, F, x
time = 30

; Echidna Sequence Punches (DM)
[Command]
name = "EchidnaSequence"
command = ~D, DF, F, D, DF, F, y
time = 30

; Echidna Sequence Punches (DM)
[Command]
name = "EchidnaSequence"
command = ~D, DF, F, D, DF, F, z
time = 30

;-| EX Special Motions |------------------------------------------------------

[Command]
name = "upperex"
command = ~F, D, DF, x+y

[Command]
name = "upperex"
command = ~F, D, DF, y+z

[Command]
name = "upperex"
command = ~F, D, DF, x+z

[Command]
name = "dashex"
command = ~D, DB, B, x+y

[Command]
name = "dashex2"
command = ~D, DB, B, y+z

[Command]
name = "dashex"
command = ~D, DB, B, x+z

[Command]
name = "stoneex"
command = ~D, DF, F, x+y

[Command]
name = "stoneex2"
command = ~D, DF, F, y+z

[Command]
name = "stoneex"
command = ~D, DF, F, x+z

;-| Special Motions |------------------------------------------------------

[Command]
name = "upperx"
command = ~F, D, DF, x

[Command]
name = "uppery"
command = ~F, D, DF, y

[Command]
name = "upperz"
command = ~F, D, DF, z

[Command]
name = "dashx"
command = ~D, DB, B, x

[Command]
name = "dashy"
command = ~D, DB, B, y

[Command]
name = "dashz"
command = ~D, DB, B, z

[Command]
name = "stonex"
command = ~D, DF, F, x

[Command]
name = "stoney"
command = ~D, DF, F, y

[Command]
name = "stonez"
command = ~D, DF, F, z
;------------------------
;-| Charges|-------------
[Command]
name = "chargedownup_a"
command = ~60$D, U, a
time = 10

[Command]
name = "chargedownup_b"
command = ~60$D, U, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = "chargebackfwd_a"
command = ~60$B, F, a
time = 10

[Command]
name = "chargebackfwd_b"
command = ~60$B, F, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
Name = "Knock_Simple"
command = x+y
time = 1

[Command]
Name= "fab"
command = /$F,a+b
time = 1

[Command]
Name= "bab"
command = /$B,a+b
time = 1

[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery";Required (do not remove)
command = y+z
time = 1

[Command]
name = "recovery";Required (do not remove)
command = x+z
time = 1
;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

; Os comandos Z e c so necessrios  introduo com msica
[Command]
name = "z"
command = z
time = 1

[Command]
name = "a"
command = a
time = 1

[Command]
name ="b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "Provocate"
command = s

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd"  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup"   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holda" ;Required (do not remove)
command = /a
time = 1

[Command]
name = "longjump"
command = D, $U
time = 18

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;------------------------------AI-------------------------------------------
;===========================================================================
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 390
triggerall = var(58)
triggerall = statetype != A
triggerall = ctrl
triggerall = enemynear, numproj = 0
triggerall = enemynear, movetype != A
triggerall = life >= 400
trigger1 = p2bodydist x >= 150
trigger1 = life >= enemynear, life
trigger1 = random <= 6 && var(58) >= 6 || random <= 20 && var(58) >= 3 && var(58) <= 5 || random <= 40 &&var(58) >= 1 && var(58) <= 2
trigger2 = p2bodydist x >= 150
trigger2 = p2statetype = L
trigger2 = random <= 12 && var(58) >= 6 || random <= 32 && var(58) >= 3 && var(58) <= 5 || random <= 56 && var(58) >= 1 && var(58) <= 2
trigger3 = win && random <= 57
;---------------------------------------------------------------------------
; Explosion Punch SDM
[State -1]
type = ChangeState
value = 3030
triggerall = ctrl
triggerall = roundstate = 2
triggerall = var(58)
triggerall = power >= 2000
triggerall = statetype != A
triggerall = ctrl
triggerall = p2statetype != A
triggerall = p2bodydist X <= 70
triggerall = p2statetype != L
trigger1 = Random < (150 * (var(58) ** 2 / 64.0))
trigger2 = enemynear, movetype = A
trigger2 = Random < (300 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Explosion Punch DM
[State -1]
type = ChangeState
value = 3020
triggerall = ctrl
triggerall = roundstate = 2
triggerall = var(58)
triggerall = power >= 1000 && power <= 1999
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = ctrl
trigger1 = p2statetype != A
trigger1 = p2bodydist X <= 70
trigger1 = Random < (150 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Echidna Sequence Punches SDM
[State -1]
type = ChangeState
value = 3010
triggerall = roundstate = 2
triggerall = var(58)
triggerall = power  >= 2000
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = ctrl
trigger1 = p2statetype != A
trigger1 = p2bodydist X <= 116
trigger1 = enemynear, ctrl = 0
trigger1 = enemynear, anim != [120,152]
trigger1 = var(58) >= 6
trigger1 = Random < (41 * (var(58) ** 2 / 64.0)) || var(58) >= 8
trigger2 = stateno = 1020 || stateno = 1021 || stateno = 1022 || stateno = 1023 || stateno = 1028
trigger2 = movecontact
trigger2 = Random < (250 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Echidna Sequence Punches DM
[State -1]
type = ChangeState
value = 3000
triggerall = roundstate = 2
triggerall = var(58)
triggerall = power  >= 1000 && power <= 1999
triggerall = statetype != A
triggerall = p2statetype != L
trigger1 = ctrl
trigger1 = p2statetype != A
trigger1 = p2bodydist X <= 84
trigger1 = enemynear, ctrl = 0
trigger1 = enemynear, anim != [120,152]
trigger1 = var(58) >= 6
trigger1 = Random < (41 * (var(58) ** 2 / 64.0)) || var(58) >= 8
trigger2 = stateno = 1020 || stateno = 1021 || stateno = 1022 || stateno = 1023 || stateno = 1028
trigger2 = movecontact
trigger2 = Random < (250 * (var(58) ** 2 / 64.0))

;---------------------------------------------------------------------------
; Shouken(EX)
[State -1]
type = ChangeState
value  = 1004
triggerall = power >= 500
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
;triggerall = p2bodydist Y <= -134
triggerall = p2bodydist X <= 98
triggerall = p2statetype != L
trigger1 = stateno = 220 || stateno = 420 || stateno = 221
trigger1 = movehit
trigger1 = Random < (200 * (var(58) ** 2 / 64.0))
trigger2 = stateno = 210 || stateno = 410
trigger2 = movehit
trigger2 = Random < (14 * (var(58) ** 2 / 64.0))
trigger3 = ctrl
trigger3 = numtarget(1024)
trigger3 = target(1024), stateno = 1027
trigger3 = Random < (24 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Echidna Dash Punch (EX2)
[State -1]
type = ChangeState
value = 1028
triggerall = power >= 500
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = p2statetype != A
triggerall = p2statetype != L
trigger1 = stateno = 220 || stateno = 221 || stateno = 420
trigger1 = movehit
trigger1 = Random < (50 * (var(58) ** 2 / 64.0))
trigger2 = ctrl
trigger2 = p2bodydist X >= 100
trigger2 = p2bodydist X <= 175
trigger2 = enemynear, numproj = 0
trigger2 = enemynear, time <= 4
trigger2 = p2statetype != A
trigger2 = enemynear, ctrl = 0
trigger2 = enemynear, anim != [120,152]
trigger2 = Random < (100 * (var(58) ** 2 / 64.0))
trigger2 = var(58) >= 6

;---------------------------------------------------------------------------
; Echidna Dash Punch (EX)
[State -1]
type = ChangeState
value = 1023
triggerall = power >= 500
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = p2statetype != A
trigger1 = stateno = 220 || stateno = 221 || stateno = 420
trigger1 = movehit
trigger1 = Random < (150 * (var(58) ** 2 / 64.0))
;-----------------------------------------------------------------------------
; Stone_Throw_EX2
[State -1]
type = ChangeState
value = 1131
triggerall = power >= 500
triggerall = roundstate = 2
triggerall = var(58)
triggerall = !numhelper(1140)
triggerall = statetype != A
triggerall = p2bodydist X >= 100
triggerall = p2movetype != A
triggerall = p2statetype != L
triggerall = p2statetype != A
trigger1 = ctrl
trigger1 = Random < (24 * (var(58) ** 2 / 64.0))
;-----------------------------------------------------------------------------
; Stone_Throw_EX
[State -1]
type = ChangeState
value = 1130
triggerall = power >= 500
triggerall = roundstate = 2
triggerall = var(58)
triggerall = !numhelper(1140)
triggerall = statetype != A
triggerall = p2bodydist X >= 100
triggerall = p2movetype != A
triggerall = p2statetype != L
triggerall = p2statetype = A
trigger1 = ctrl
trigger1 = Random < (24 * (var(58) ** 2 / 64.0))

;---------------------------------------------------------------------------
; Shouken(Weak)
[State -1]
type = ChangeState
value  = 1000
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
;triggerall = p2bodydist Y <= -80
triggerall = p2bodydist X <= 51
triggerall = p2statetype != L
trigger1 = ctrl
trigger1 = enemynear, ctrl = 0
trigger1 = enemynear, anim != [120,152]
trigger1 = Random < (24 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Shouken(Med)
[State -1]
type = ChangeState
value  = 1001
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
;triggerall = p2bodydist Y <= -128
triggerall = p2bodydist X <= 67
triggerall = p2statetype != L
triggerall = ctrl
triggerall = p2statetype = A
trigger1 = Random < (34 * (var(58) ** 2 / 64.0))
trigger2 = enemynear, ctrl = 0
trigger2 = Random < (64 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Shouken(Flame)
[State -1]
type = ChangeState
value  = 1002
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
;triggerall = p2bodydist Y <= -134
triggerall = p2bodydist X <= 98
triggerall = p2statetype != L
trigger1 = stateno = 220 || stateno = 420 || stateno = 221
trigger1 = movehit
trigger1 = Random < (250 * (var(58) ** 2 / 64.0))
trigger2 = stateno = 210 || stateno = 410
trigger2 = movehit
trigger2 = Random < (14 * (var(58) ** 2 / 64.0))
trigger3 = ctrl
trigger3 = numtarget(1024)
trigger3 = target(1024), stateno = 1027
trigger3 = Random < (64 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Echidna Dash Punch (quick)
[State -1]
type = ChangeState
value = 1020
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = p2statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X <= 116
trigger1 = enemynear, numproj = 0
trigger1 = p2movetype != A
trigger1 = p2statetype != L
trigger1 = Random < (34 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Echidna Dash Punch (med)
[State -1]
type = ChangeState
value = 1021
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = p2statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X <= 155
trigger1 = p2bodydist X >= 117
trigger1 = enemynear, numproj = 0
trigger1 = p2movetype != A
trigger1 = p2statetype != L
trigger1 = Random < (29 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Echidna Dash Punch (hard)
[State -1]
type = ChangeState
value = 1022
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = p2statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X <= 175
trigger1 = p2bodydist X >= 155
trigger1 = enemynear, numproj = 0
trigger1 = p2movetype != A
trigger1 = p2statetype != L
trigger1 = Random < (23 * (var(58) ** 2 / 64.0))
trigger2 = stateno = 220 || stateno = 221 || stateno = 420
trigger2 = movehit
trigger2 = Random < (250 * (var(58) ** 2 / 64.0))

;-----------------------------------------------------------------------------
; Stone_Throw_Close
[State -1]
type = null;ChangeState
value = 1100
triggerall = roundstate = 2
triggerall = var(58)
triggerall = !numhelper(1140)
triggerall = statetype != A
triggerall = p2bodydist X <= 128
triggerall = p2statetype = A
triggerall = p2movetype != A
trigger1 = ctrl
trigger1 = Random < (12 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Stone_Throw_Medium
[State -1]
type = ChangeState
value = 1110
triggerall = roundstate = 2
triggerall = var(58)
triggerall = !numhelper(1140)
triggerall = statetype != A
triggerall = p2bodydist X <= 190
triggerall = p2bodydist X >= 120
triggerall = p2movetype != A
trigger1 = ctrl
trigger1 = Random < (20 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Stone_Throw_Far
[State -1]
type = ChangeState
value = 1120
triggerall = roundstate = 2
triggerall = var(58)
triggerall = !numhelper(1140)
triggerall = statetype != A
triggerall = p2bodydist X >= 150
triggerall = p2movetype != A
trigger1 = ctrl
trigger1 = Random < (20 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; AI Glide
[State -1]
type = ChangeState
value = 1050
triggerall = roundstate = 2
triggerall = var(58)
triggerall = p2bodydist X >= 138
trigger1 = Random < (38 * (var(58) ** 2 / 64.0))
trigger1 = statetype = A
trigger1 = ctrl
;---------------------------------------------------------------------------
;AI Stun
[State -1, AI Stun]
type = ChangeState
value = 900
triggerall = var(20)
triggerall = var(58)
triggerall = roundstate = 2
triggerall = statetype != A
triggerall = ctrl
triggerall = p2bodydist X <= 80
triggerall = p2statetype != A
triggerall = !numtarget(910)
triggerall = p2movetype != H
trigger1 = Random < (32 * (var(58) ** 2 / 64.0))
trigger2 = p2statetype = L
trigger2 = Random < (122 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
;AI Throw
[State -1, AI Throw]
type = ChangeState
value = 800
triggerall = var(58)
triggerall = roundstate = 2
triggerall = statetype != A
triggerall = ctrl
triggerall = p2statetype != L
triggerall = p2movetype != A
triggerall = p2movetype != H
trigger1 = p2bodydist x <= 28 && p2statetype != A
trigger1 = Random < (64 * (var(58) ** 2 / 64.0))
trigger2 = enemynear, anim >= 120 && enemynear, anim <= 152 && p2bodydist x <= 28
trigger2 = p2statetype != A
trigger2 = var(58) >= 6

;---------------------------------------------------------------------------
[State -1, AI Fwd dodge]
type = ChangeState
value = 255
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = ctrl
triggerall = p2movetype != H
trigger1 = p2movetype = A
trigger1 = enemynear, time <= 4
trigger1 = Random < (8 * (var(58) ** 2 / 64.0))
trigger1 = p2bodydist X <= 50
trigger1 = var(58) >= 5
trigger2 = p2bodydist X >= 100 && Random < (3 * (var(58) ** 2 / 64.0))

;---------------------------------------------------------------------------
[State -1, AI Backwards dodge]
type = ChangeState
value = 255
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = ctrl
triggerall = p2movetype != H
trigger1 = p2movetype = A
trigger1 = enemynear, time <= 4
trigger1 = Random < (12 * (var(58) ** 2 / 64.0))
trigger1 = p2bodydist X <= 50
trigger1 = var(58) >= 5

;---------------------------------------------------------------------------
[State -1, AI Leap Back]
type = ChangeState
value = 105
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = ctrl
trigger1 = p2statetype = L && p2bodydist X <= 60
trigger1 = Random < (6 * (var(58) ** 2 / 64.0))

;---------------------------------------------------------------------------
;AI Run Fwd
[State -1, AI Run Fwd]
type = ChangeState
value = 100
Triggerall=!Inguarddist
triggerall = roundstate = 2
triggerall = var(58)
triggerall = roundstate = 2
triggerall = statetype != A
triggerall = ctrl
triggerall = stateno != 100
triggerall = p2movetype != A
trigger1 = p2bodydist x >= 100
trigger1 = Random < (24 * (var(58) ** 2 / 64.0))
trigger2 = p2statetype = L
trigger2 = Random < (112 * (var(58) ** 2 / 64.0))

;---------------------------------------------------------------------------
;Stand_Weak_Punch
[State -1]
type = ChangeState
value = 200
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = ctrl
triggerall = p2statetype != L
triggerall = p2statetype != A
trigger1 = p2bodydist X <= 40
trigger1 = Random < (100 * (var(58) ** 2 / 64.0))

;---------------------------------------------------------------------------
;Stand_Fierce_Punch
[State -1]
type = ChangeState
value = 210
triggerall = Random < (250 * (var(58) ** 2 / 64.0))
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
trigger1 = p2bodydist X <= 40
trigger1 = stateno = 200 || stateno = 400
trigger1 = movecontact
;---------------------------------------------------------------------------
;Command Attack
[State -1]
type = ChangeState
value = 221
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = ctrl
triggerall = p2statetype != L
triggerall = enemynear, numproj = 0
triggerall = enemynear, movetype != A
triggerall = p2statetype != A
trigger1 = p2bodydist X <= 47
trigger1 = p2bodydist x >= 20
trigger1 = Random < (64* (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
;Stand_Light_Kick
[State -1]
type = ChangeState
value = 220
triggerall = var(58)
triggerall = roundstate = 2
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = enemynear, numproj = 0
triggerall = enemynear, movetype != A
triggerall = p2statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X <= 45
trigger1 = p2bodydist x >= 20
trigger1 = Random < (250 * (var(58) ** 2 / 64.0))
trigger2 = stateno = 210 || stateno = 410
trigger2 = movecontact
trigger2 = p2bodydist X >= 30
;---------------------------------------------------------------------------
; Crouch_Light_Punch
[State -1]
type = ChangeState
value = 400
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = ctrl
triggerall = p2statetype = S
trigger1 = p2bodydist X <= 35
trigger1 = Random < (100 * (var(58) ** 2 / 64.0))
;---------------------------------------------------------------------------
; Crouch_Hard_Punch
[State -1]
type = ChangeState
value = 410
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = p2statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X <= 61
trigger1 = p2bodydist X >= 36
trigger1 = Random < (34 * (var(58) ** 2 / 64.0))
trigger2 = stateno = 400 || stateno = 200
trigger2 = movecontact
trigger2 = p2bodydist X >= 41
;---------------------------------------------------------------------------
;Crouch_Light_Kick
[State -1]
type = ChangeState
value = 420
triggerall = var(58)
triggerall = roundstate = 2
triggerall = statetype != A
trigger1 = p2bodydist X <= 40
trigger1 = p2statetype != C
trigger1 = stateno = 210 || stateno = 410
trigger1 = movecontact
trigger1 = Random < (250 * (var(58) ** 2 / 64.0))
;--------------------------------------------------------------------------
;Jump_Light_Kick
[State -1]
type = ChangeState
value = 620
triggerall = roundstate = 2
triggerall = var(58)
triggerall = statetype = A
triggerall = ctrl
triggerall = p2statetype != L
triggerall = p2bodydist Y <= 80
triggerall = p2bodydist X <= 71
trigger1 = Random < (250 * (var(58) ** 2 / 64.0))

[State -1]
Type=Changestate
Triggerall=Inguarddist ; Guard when in guard distance
triggerall = var(58) = 3 && random <= 64 || var(58) = 4 && random <= 72 || var(58) = 5 && random <= 108 || var(58) = 6 && random <= 250 || var(58) = 7 && random <=500 || var(58) = 8 && random <= 999 ; and the AI is on
trigger1 = stateno!=[120,160]
Trigger1=ctrl ; and we have control
value=120

;===========================================================================
;----------------------------HUMAN------------------------------------------
;===========================================================================
; Super Motions
;---------------------------------------------------------------------------
; Explosion Punch SDM
[State -1]
type = ChangeState
value = 3030
triggerall = !var(58)
triggerall = command = "XplodSDM"
triggerall = power  >= 2000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 1020
trigger8 = movecontact
trigger9 = stateno = 1021
trigger9 = movecontact
trigger10 = stateno = 1022
trigger10 = movecontact
trigger11 = stateno = 1023
trigger11 = movecontact
trigger12 = stateno = 1028
trigger12 = movecontact
trigger13 = stateno = 221
trigger13 = movecontact
;---------------------------------------------------------------------------
; Explosion Punch DM
[State -1]
type = ChangeState
value = 3020
triggerall = !var(58)
triggerall = command = "XplodDM"
triggerall = power  >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 1020
trigger8 = movecontact
trigger9 = stateno = 1021
trigger9 = movecontact
trigger10 = stateno = 1022
trigger10 = movecontact
trigger11 = stateno = 1023
trigger11 = movecontact
trigger12 = stateno = 1028
trigger12 = movecontact
trigger13 = stateno = 221
trigger13 = movecontact
;---------------------------------------------------------------------------
; Echidna Sequence Punches SDM
[State -1]
type = ChangeState
value = 3010
triggerall = !var(58)
triggerall = command = "EchidnaSequenceSDM"
triggerall = power  >= 2000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 1020
trigger8 = movecontact
trigger9 = stateno = 1021
trigger9 = movecontact
trigger10 = stateno = 1022
trigger10 = movecontact
trigger11 = stateno = 1023
trigger11 = movecontact
trigger12 = stateno = 1028
trigger12 = movecontact
trigger13 = stateno = 221
trigger13 = movecontact
;---------------------------------------------------------------------------
; Echidna Sequence Punches DM
[State -1]
type = ChangeState
value = 3000
triggerall = !var(58)
triggerall = command = "EchidnaSequence"
triggerall = power  >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 1020
trigger8 = movecontact
trigger9 = stateno = 1021
trigger9 = movecontact
trigger10 = stateno = 1022
trigger10 = movecontact
trigger11 = stateno = 1023
trigger11 = movecontact
trigger12 = stateno = 1028
trigger12 = movecontact
trigger13 = stateno = 221
trigger13 = movecontact
;===========================================================================
; EX Special Moves
;---------------------------------------------------------------------------
; Shouken(EX)
[State -1]
type = ChangeState
value  = 1004
triggerall = !var(58)
triggerall = command = "upperex"
triggerall = power >= 500
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Echidna Dash Punch (EX2)
[State -1]
type = ChangeState
value = 1028
triggerall = !var(58)
triggerall = command = "dashex2"
triggerall = power >= 500
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Echidna Dash Punch (EX)
[State -1]
type = ChangeState
value = 1023
triggerall = !var(58)
triggerall = command = "dashex"
triggerall = power >= 500
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;-----------------------------------------------------------------------------
; Stone_Throw_EX2
[State -1]
type = ChangeState
value = 1131
triggerall = !var(58)
triggerall = command = "stoneex2"
triggerall = power >= 500
triggerall = !numhelper(1140)
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;-----------------------------------------------------------------------------
; Stone_Throw_EX
[State -1]
type = ChangeState
value = 1130
triggerall = !var(58)
triggerall = command = "stoneex"
triggerall = power >= 500
triggerall = !numhelper(1140)
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;===========================================================================
; Special Moves
;---------------------------------------------------------------------------
; Shouken(Weak)
[State -1]
type = ChangeState
value  = 1000
triggerall = !var(58)
triggerall = command = "upperx"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Shouken(Med)
[State -1]
type = ChangeState
value  = 1001
triggerall = !var(58)
triggerall = command = "uppery"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Shouken(Flame)
[State -1]
type = ChangeState
value  = 1002
triggerall = !var(58)
triggerall = command = "upperz"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Glide
[State -1]
type = ChangeState
value = 1050
triggerall = !var(58)
triggerall = command = "FF"
trigger1 = statetype = A
trigger1 = ctrl
;---------------------------------------------------------------------------
; Echidna Dash Punch (quick)
[State -1]
type = ChangeState
value = 1020
triggerall = !var(58)
triggerall = command = "dashx"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Echidna Dash Punch (med)
[State -1]
type = ChangeState
value = 1021
triggerall = !var(58)
triggerall = command = "dashy"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Echidna Dash Punch (hard)
[State -1]
type = ChangeState
value = 1022
triggerall = !var(58)
triggerall = command = "dashz"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;-----------------------------------------------------------------------------
; Stone_Throw_Close
[State -1]
type = ChangeState
value = 1100
triggerall = !var(58)
triggerall = command = "stonex"
triggerall = !numhelper(1140)
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Stone_Throw_Medium
[State -1]
type = ChangeState
value = 1110
triggerall = !var(58)
triggerall = command = "stoney"
triggerall = !numhelper(1140)
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Stone_Throw_Far
[State -1]
type = ChangeState
value = 1120
triggerall = !var(58)
triggerall = command = "stonez"
triggerall = !numhelper(1140)
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 400
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
trigger6 = stateno = 220
trigger6 = movecontact
trigger7 = stateno = 420
trigger7 = movecontact
trigger8 = stateno = 221
trigger8 = movecontact
;---------------------------------------------------------------------------
; Basic Moves
;---------------------------------------------------------------------------
;Backward Dodge
[State -1]
type = ChangeState
value = 256
triggerall = !var(58)
triggerall = command = "x" && command = "y" || command = "b"
triggerall = command = "holdback"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Stun
[State -1, Stun]
type = ChangeState
value = 900
triggerall = var(20)
triggerall = !var(58)
triggerall = command = "a"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Forward Dodge 
[State -1]
type = ChangeState
value = 255
triggerall = !var(58)
triggerall = command = "x" && command = "y" || command = "b"
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = !var(58)
triggerall = command = "y" && command = "z" || command = "c"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
triggerall = !var(58)
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
triggerall = !var(58)
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Provocate
[State -1]
type = ChangeState
value = 390
triggerall = !var(58)
triggerall = command = "Provocate"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Stand_Weak_Punch
[State -1]
type = ChangeState
value = 200
triggerall = !var(58)
triggerall = command = "x"          ;Place name of command here
triggerall = command != "holddown"  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand_Fierce_Punch
[State -1]
type = ChangeState
value = 210
triggerall = !var(58)
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 400
trigger3 = movecontact
;---------------------------------------------------------------------------
;Command Attack
[State -1]
type = ChangeState
value = 221
triggerall = !var(58)
triggerall = command = "z" && command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
;Stand_Light_Kick
[State -1]
type = ChangeState
value = 220
triggerall = !var(58)
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 400
trigger3 = movecontact
trigger4 = stateno = 210
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
;---------------------------------------------------------------------------
; Crouch_Light_Punch
[State -1]
type = ChangeState
value = 400
triggerall = !var(58)
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
;---------------------------------------------------------------------------
; Crouch_Hard_Punch
[State -1]
type = ChangeState
value = 410
triggerall = !var(58)
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 400
trigger3 = movecontact
;---------------------------------------------------------------------------
;Crouch_Light_Kick
[State -1]
type = ChangeState
value = 420
triggerall = !var(58)
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact
trigger3 = stateno = 400
trigger3 = movecontact
trigger4 = stateno = 210
trigger4 = movecontact
trigger5 = stateno = 410
trigger5 = movecontact
;---------------------------------------------------------------------------
;Jump_Light_Punch
[State -1]
type = ChangeState
value = 600
triggerall = !var(58)
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Jump_Hard_Punch
[State -1]
type = ChangeState
value = 610
triggerall = !var(58)
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
;--------------------------------------------------------------------------
;Jump_Light_Kick
[State -1]
type = ChangeState
value = 620
triggerall = !var(58)
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
;--------------------------------------------------------------------------